#' FP injury table
#'
#' This dataframe contains a column (`prob_gp`) for each positional ranking that describes the probability of a player with that preseason ADP playing in a given game. It is modelled from historical rankings data and the number of games played per season for a given positional rank.
#'
"fp_injury_table"

#' Historical draft position ranks
#'
#' This dataframe has historical positional draft rankings for 2012-2020 QB/RB/WR/TE/PK and 2015-2020 DL/LB/DB, as gathered by the ffpros package.
#'
"fp_rankings_history"

#' Historical position ranks
#'
#' This dataframe has historical positional in-season rankings for 2012-2020 QB/RB/WR/TE/PK and 2015-2020 DL/LB/DB, as gathered by the ffpros package.
#'
"fp_rankings_history_week"
